#line 2 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/lexer.c"

#line 4 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 158
#define YY_END_OF_BUFFER 159
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1174] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      159,  157,   98,  101,  157,  157,  157,  157,  157,  103,
      103,  157,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  157,   98,  157,  156,  155,  156,  156,  114,
      112,  114,  100,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
       98,  157,   99,   98,  157,    0,  108,    0,    0,  110,
        0,    0,  103,    0,  107,  104,  107,  111,  102,  104,
        0,  104,  103,    0,   61,  106,  106,  106,  106,  106,

      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,   62,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  113,  106,  106,  106,  106,  106,  106,  106,   78,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,    0,    0,    0,    0,    0,    0,    0,
      104,   63,  107,  104,  102,  104,    0,  104,  105,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,

      106,  106,  106,   39,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   13,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  106,  106,  106,
      106,  106,  106,   77,  106,  106,  106,  106,  106,  106,
      106,   86,  106,  106,  106,  106,  106,    0,    0,    0,
      104,   52,  106,  106,  106,  106,  106,   37,   35,  106,
      106,  106,   45,  106,  106,  106,  106,   40,  106,  106,

      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,   50,  106,  106,  106,  106,   43,  106,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    8,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  154,  106,
       96,  106,  106,  106,  106,  106,  106,  106,   82,  106,
      106,  106,  106,  106,   89,  106,  106,    9,  109,  106,
      106,  106,  106,  106,  106,   23,   48,  106,  106,   51,
       59,   41,  106,  106,  106,  106,  106,   38,  106,  106,

      106,   32,  106,  106,  106,   56,  106,   25,  106,  106,
      106,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   97,  106,  106,  106,  106,  106,  106,  106,  106,
       84,  106,  106,  106,  106,  106,  106,  106,  106,  106,
       34,  106,  106,   42,  106,  106,  106,  106,  106,   26,
      106,   46,   60,   49,   24,  106,  106,  106,  106,  106,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  106,  106,  106,   76,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,   33,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,   28,  106,   29,  106,   53,  106,   44,   36,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   14,    0,    0,    0,    0,    0,    0,   18,

        0,    0,   20,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,   95,
      106,  106,   31,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,   57,  106,   55,  106,   58,   47,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  119,
        0,    0,    0,    0,  125,   11,    0,    0,    0,  151,
        0,   15,    0,    0,   16,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  152,    0,    0,
        0,    0,    0,    0,    0,  106,  106,  106,  106,   80,

       81,   83,  106,  106,  106,  106,  106,   73,  106,   30,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
       54,   27,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   21,    0,    0,   22,  135,
        0,    0,  132,    0,    0,    0,  106,  106,  106,  106,
      106,   87,   88,  106,  106,   74,  106,  106,   67,   72,
       66,  106,  106,  106,   70,  106,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,  149,   10,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   19,    0,    0,    0,
      146,    0,    0,    0,    0,    0,    0,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,   69,   65,   75,
      150,    1,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   17,  136,  134,    0,  145,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  106,
      106,  106,  106,  106,  106,  106,   71,  106,   64,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  141,    0,    0,    0,
        0,    0,    0,    0,    0,  122,    0,    0,    0,    0,
        0,    0,  106,  106,  106,  106,  106,  106,  106,  106,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      144,    0,    0,    0,    0,    0,  148,    0,    0,    0,
        0,  106,  106,  106,  106,  106,  106,  106,   68,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   12,    0,    0,
        0,    0,  137,    0,    0,    0,    0,    0,  106,  106,

      106,  106,   85,  106,  106,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  140,    0,    0,    0,    0,  127,    0,    0,
        0,    0,  106,   93,  106,  106,  106,   91,  142,    0,
        0,    0,    0,    0,    2,    0,    0,    0,    0,    5,
        6,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      138,    0,    0,  106,  106,  106,  106,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    7,    0,    0,  131,
        0,  126,    0,    0,    0,    0,    0,  106,  106,   79,
      106,    0,    0,  117,    0,    0,    0,    0,  121,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,  106,
      106,   90,    0,    0,    0,    0,    0,    0,    0,    0,
      124,    0,  129,    0,    0,    0,  139,    0,  106,  106,
      118,  115,    0,  143,  120,    0,    0,    0,    0,    0,
        0,  133,  153,  106,  106,  116,    0,    0,    0,  147,
        0,    0,  106,  106,  123,    0,    0,    0,  128,   92,
      106,    3,    0,  130,  106,    0,  106,    0,  106,    4,
      106,   94,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    1,    1,    6,    1,    7,    8,
        9,   10,   11,    1,   12,   13,   14,   15,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   17,    1,    1,
        1,    1,    1,    1,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   28,   41,   42,
        1,   43,    1,    1,   44,    1,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   28,   54,   55,   56,   57,
       58,   59,   28,   60,   61,   62,   63,   64,   65,   66,
       67,   68,    1,   69,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[70] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    3,    3,    4,    4,    1,    4,    4,    4,
        4,    4,    4,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    1,    3,    4,    4,    4,    4,    4,    4,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    1
    } ;

static yyconst flex_int16_t yy_base[1182] =
    {   0,
        0,   68, 2741,   69,   70,   73,   75,   75, 2735,   80,
     2742, 2745, 2745, 2745,   73,   84,   77,   87,   75,  127,
     2675, 2723,   82,   93,   96,  101,  134,  139,  154,  145,
      105,  160,  166,  171,  174,  182,  186,  204,  212,  208,
      218,  221, 2670,  202,  262, 2745, 2745,  205, 2716, 2745,
     2745, 2723, 2745,  224,  230,  238,  261,  290,  296,  308,
      311,  314,  317,  320,  323,  330,  359,  364,  333,  374,
      208, 2714, 2745,  252, 2713,  149, 2745, 2731,  260, 2745,
      308,  154, 2667,  177,  379,  384,  233, 2745,    0,  387,
      369, 2745, 2745,    0, 2745,  406,  416,  426,  429,  434,

      437,  440,  443,  446,  449,  459,  462,  465,  468,  477,
      480,  484,  487,  495,  492,  501,  504,  514,  517,  524,
      520,  539,  542,  545,  554,  558,  566,  573, 2745,  312,
        0,  192, 2706, 2673,  106,  196,  303,  228, 2677,  310,
     2676,  377,  535,  352, 2679,   44, 2670, 2673,  462, 2703,
     2667, 2745,  584,  588,  597,  600,  608,  614,  617,  620,
      623,  628,  631,  635,  647,  650,  654,  657,  663,  668,
      674,  680,  687,  481, 2701, 2656,  517, 2699,  239,  745,
      689,  326,  706,  341,    0,  720,  186,  558,    0,  694,
      737,  745,  732,  741,  713,  765,  768,  771,  774,  787,

      790,  793,  796,  799,  802,  806,  809,  819,  822,  831,
      834,  844,  847,  850,  853,  858,  861,  864,  867,  875,
      878,  885,  890,  893,  897, 2673, 2657,  254,  504, 2668,
     2670, 2668,  530, 2670, 2657,   84, 2651, 2664, 2745, 2652,
      636, 2663, 2650, 2646, 2659, 2659,  249, 2644,  346, 2651,
     2648, 2640, 2645, 2641, 2646, 2638, 2649,  905,  913,  916,
      919,  931,  934,  937,  941,  944,  951,  955,  958,  965,
      968,  971,  974,  979,  984,  995,  989, 2648, 2688, 1001,
     1006, 1011, 1022, 1028, 1031, 1034, 1039, 1045, 1048, 1051,
     1056, 1064, 1067, 1070, 1073, 1078, 1081, 1084, 1087, 1090,

     1093, 1096, 1101, 1112, 1115, 1118, 1127, 1137, 1144, 1153,
     1156, 1159, 1163, 1166, 1169, 1172, 1180, 1183, 2645, 2635,
     2643, 2642, 2631, 2625, 2621, 2642, 2625, 2745, 2636, 2626,
     2623, 2620, 2636, 2625, 2619, 2658, 2628, 2618, 2620, 2612,
     2611, 2623, 2612, 2618, 2606, 2614, 2605, 2615, 2603,  620,
     2605, 2602, 2613, 2641, 2611, 2610, 2596, 2595, 2745, 1187,
     1190, 1193, 1200, 1203, 1212, 1215, 1218, 1225, 1228, 1233,
     1236, 1242, 1248, 1251, 1255, 1262, 1258, 2745, 2745, 1265,
     1271, 1274, 1286, 1296, 1302, 1306, 1315, 1318, 1321, 1327,
     1330, 1333, 1336, 1339, 1342, 1345, 1349, 1352, 1357, 1360,

     1363, 1366, 1369, 1372, 1375, 1385, 1393, 1397, 1401, 1405,
     1409, 2595, 2622, 2592, 2598, 2594, 2602, 2597, 2586, 2586,
     2588, 2586, 2600, 2581, 2588, 2593, 2596, 2582, 2608, 2578,
     2574, 2583, 2590, 2577, 2584, 2574, 2576, 2575, 2579, 2575,
     2601, 2569, 2576, 2575, 2574, 2577, 2563, 2565,  344,  207,
     2556, 1414, 1417, 1423, 1426, 1431, 1434, 1442, 1447, 1452,
     1455, 1458, 1461, 1464, 1476, 1484, 1487, 1490, 1498, 1501,
     1508, 1555, 1515, 1518, 1526, 1535, 1538, 1521, 1541, 1544,
     1547, 1550, 1559, 1569, 1576, 1581, 1585, 1588, 1592, 1597,
     2557, 2550, 1593, 2567, 2554, 2554, 2556, 2557, 2551, 2548,

     2547, 2561, 2547, 2553, 2560, 2540, 2555, 2557, 2539, 2552,
     2554, 2541, 2536, 2548, 2547, 2545, 2544, 2534, 2534, 2533,
     2536, 2526, 2527, 2566, 2524, 2536, 2530, 2524,  604, 2523,
     2522, 2534, 1602, 1605, 1608, 1611, 1618, 1626, 1632, 1637,
     1640, 1644, 1648, 1651, 1659, 1662, 1666, 1673, 1676, 1682,
     1685, 1699, 1712, 1715, 1718, 1721, 1729, 1735, 1738, 1741,
     1747, 1750, 1753, 1756, 1765, 1769, 1772, 1775, 1778, 1783,
     2558, 2546, 2513, 2523, 2525, 2524, 2512, 2526, 2517, 2507,
     2517, 2505, 2513, 2512, 2515, 2501, 2513, 2500, 2500, 2510,
     2509, 2499, 2745, 2483, 2476, 2483, 2480, 2491, 2507,  712,

     2505, 2464, 2745, 2470, 2459, 2468, 2457, 2460, 2468, 2467,
     2458, 2466, 2468, 2453, 2461, 2447, 2452, 1786, 1794, 1799,
     1802, 1807, 1812, 1815, 1818, 1821, 1824, 1827, 1836, 1845,
     1850, 1853, 1862, 1865, 1870, 1873, 1882, 1888, 1891, 1895,
     1901, 1913, 1916, 1919, 1923, 1927, 1930, 1935, 1938, 2448,
     2460, 2454, 2458, 2457, 2450, 2447, 2434, 2431,  138, 2745,
     1125, 2435, 2425, 2434, 2745, 2745, 2430, 2453, 2412, 2745,
     2421, 2745, 2411, 2410, 2745, 2378, 2382, 2381, 2382, 2364,
     2334, 2322, 2330, 2319, 2309, 2320, 2343, 2745, 2313, 2291,
     2291, 2261, 2273, 2251,  464, 1941, 1944, 1947, 1950, 1953,

     1956, 1961, 1967, 1970, 1975, 1984, 1987, 1990, 1993, 1996,
     1999, 2012, 2015, 2018, 2023, 2031, 2044, 2049, 2053, 2056,
     2059, 2067, 2241, 2232, 2236, 2220, 2231, 2257, 2214, 2225,
     2215, 2168, 2169, 2163, 2147, 2153, 2137, 2129, 2106,  566,
     2100, 2099, 2091, 2090, 2082, 2122, 2081, 2090, 2089, 2083,
     2078, 2052, 2024, 2031, 2026, 2745, 2010, 1996, 2745, 2745,
     2002, 2030, 2745, 2021, 2001, 1982, 2070, 2073, 2076, 2079,
     2082, 2085, 2089, 2092, 2095, 2098, 2103, 2106, 2109, 2118,
     2122, 2133, 2136, 2142, 2147, 2153, 1990, 1989, 1984, 2004,
     2002, 1962, 1969, 1998, 1985, 1956,  474, 1947, 1945, 1929,

     1926, 2745, 2745, 1928, 1909, 1918, 1897, 1874, 1863, 1874,
     1859, 1867, 1862, 1861, 1858, 1843, 2745, 1846, 1817, 1851,
     2745, 1821, 1808, 1802, 1798,   79, 1794, 2156, 2159, 2162,
     2165, 2169, 2172, 2175, 2179, 2182, 2193, 2185, 2196, 2199,
     2745, 2745, 1792, 1788, 1782, 1781, 1823, 1759, 1759, 1753,
     1741, 1735, 1740, 1735, 1730, 1725, 1727, 1712, 1699, 1707,
     1725, 1694, 1675, 1688, 2745, 2745, 2745, 1672, 2745, 1665,
     1665, 1658, 1665, 1689, 1660, 1659, 1649, 1656, 1643, 2206,
     2212, 2219, 2222, 2225, 2228, 2231, 2234, 2237, 2240, 1680,
     1642, 1641, 1626, 1606, 1617, 1600, 1605, 1595, 1577, 1572,

     1579, 1564, 1547, 1538, 1536, 1521, 2745, 1507, 1499, 1490,
     1476, 1464, 1465, 1456, 1458, 2745, 1447, 1446, 1437, 1471,
     1434, 1425, 2243, 2246, 2249, 2255, 2258, 2270, 2279, 2282,
     1425, 1432, 1430, 1417, 1413, 1407, 1389, 1384, 1429, 1392,
     1373, 1379, 1357, 1341, 1353, 1375, 1374, 1345, 1342, 1332,
     2745, 1340, 1275, 1280, 1273, 1273, 2745, 1250, 1246, 1253,
     1276, 2285, 2288, 2293, 2296, 2304, 2307, 2313, 2316, 1247,
     1245, 1243, 1270, 1230, 1210, 1203, 1193, 1196, 1214, 1180,
     1165, 1160, 1151, 1150, 1156, 1140, 1140, 2745, 1130, 1105,
     1114, 1091, 2745, 1103, 1096, 1094, 1077, 1091, 2319, 2330,

     2323, 2334, 2337, 2344, 2340, 1085, 1061, 1060, 1059, 1067,
     1051, 1039, 1025, 1028, 1013,  997,  998,  989,  978, 1012,
      973,  979, 2745,  999,  964,  948,  952, 2745,  950,  945,
      969,  918, 2347, 2353, 2357, 2361, 2368, 2374, 2745,  953,
      941,  911,  880,  919, 2745,  917,  874,  886,  872, 2745,
     2745,  865,  855,  846,  851,  837,  844,  832,  824,  848,
     2745,  796,  804, 2383, 2386, 2389, 2392,  792,  791,  791,
      819,  779,  770,  766,  776,  679, 2745,  776,  777, 2745,
      727, 2745,  714,  705,  698,   31,   69, 2395, 2398, 2401,
     2404,   96,  133, 2745,  170,  212,  222,  287, 2745,  259,

      297,  309,  303,  340,  348,  395,  377,  395,  417, 2407,
     2413, 2416,  420,  453,  476,  490,  491,  488,  488,  498,
     2745,  516, 2745,  563,  536,  557, 2745,  556, 2421, 2424,
     2745, 2745,  568, 2745, 2745,  575,  568,  581,  605,  598,
      617, 2745, 2745, 2430, 2435, 2745,  623,  628,  639, 2745,
      647,  654, 2439, 2449, 2745,  651,  654,  679, 2745, 2443,
     2454, 2745,  667, 2745, 2464,  674, 2467,  691, 2477, 2745,
     2473, 2485, 2745, 2533, 2537, 2541, 2545, 2547, 2549, 2553,
      737
    } ;

static yyconst flex_int16_t yy_def[1182] =
    {   0,
     1173,    1, 1174, 1174, 1175, 1175,    1,    7,    1,    1,
     1173, 1173, 1173, 1173, 1176, 1177, 1173, 1178, 1173, 1173,
       20, 1173, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1173,   45, 1173, 1173,   45, 1176, 1173, 1176, 1177, 1173,
     1177, 1173,   20, 1178, 1178, 1178, 1178, 1173, 1180, 1173,
     1173, 1173, 1173, 1181, 1173, 1179, 1179, 1179, 1179, 1179,

     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1173, 1173,
       45, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1173,   45, 1173, 1173,   45, 1173, 1177,
     1173, 1178, 1178, 1178, 1180, 1173, 1173, 1173, 1181, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,

     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1173,  180, 1178,
     1178, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,

     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1173, 1173, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,

     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,

     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,

     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1179, 1179, 1179, 1179, 1179,

     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,

     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179, 1179, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179,
     1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,

     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1179, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179, 1179,

     1179, 1179, 1179, 1179, 1179, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1179, 1179, 1179, 1179, 1179, 1179, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1179, 1179, 1179, 1179, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179, 1179, 1179,
     1179, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,

     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179,
     1179, 1179, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1179, 1179,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1179, 1179, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1179, 1179, 1173, 1173, 1173, 1173, 1173, 1179,
     1179, 1173, 1173, 1173, 1179, 1173, 1179, 1173, 1179, 1173,
     1179, 1179,    0, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173
    } ;

static yyconst flex_int16_t yy_nxt[2815] =
    {   0,
       12,   13,   14,   13,   15,   12,   16,   12,   12,   12,
       12,   17,   18,   19,   20,   21,   22,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       24,   23,   25,   26,   23,   27,   23,   23,   23,   23,
       23,   23,   12,   23,   23,   28,   29,   30,   31,   32,
       23,   23,   33,   23,   34,   23,   35,   36,   37,   23,
       38,   39,   40,   41,   42,   23,   23,   23,   43,   44,
       48,   47,   51,   45,   49,   51,   71,   77, 1108,   52,
       72,   74,   52,   53,   88,   75,   80,   73,   89,   82,
       80,   83,   83,   84,   87,   84,  253,   54,   84,   85,

       84,   86,   86,  334,   84,   87,   84,   84,   87,   84,
      254,   55,   84,   87,   84,   78,   84,   87,   84,   56,
      335,   57,   58, 1109,   59,   60,   81,   61,   62,   63,
       97,   64,   65,  877,   66,   67,   68,   69,   70,   90,
      878,   83,   83, 1113,   99,   84,   87,   84,   91,   92,
       84,   87,   84,   77,  230,   93,   84,   87,   84,  100,
      732,  106,   98,  231,   93,   84,   87,   84,  181,  181,
      107,   84,   87,   84,  733,   91,   92,   84,   87,   84,
     1114,   93,   84,   87,   84,   84,   87,   84,   84,   93,
       84,   78,   94,   84,   87,   84,  101,   84,   87,   84,

      188,  188,  105,  130,  108,  102,  149,  131,  103,  174,
      150,  104,  109,  175,  110,   84,   87,   84,  113,   84,
       87,   84,  111,   84,   87,   84,  530, 1115,  112,   84,
       87,   84,   84,   87,   84,   84,   87,   84,  226,  531,
      114,   84,   87,   84,   84,  115,   84,  236,  116,   84,
       87,   84,  232,  177,  227,  117,  118,  178,  119, 1116,
      121,  233,   80,  122,  125,  120,   80,  128,  153, 1117,
      126,  123,   84,   87,   84,  127,  237,  321,  124,  132,
      133,  134,  135,  136,  137,  138,  139,  140,  322,  154,
      141,  142,  155,  347,  143,  278,  144,  145,  146,  147,

      148,   84,   87,   84,  233,  156, 1118,   84,   87,   84,
       80,  348,  102,  130,   80,  103, 1119,  131,  104,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,  157,   84,
      108,   84,   87,   84,   84,   87,   84,  105,  109, 1120,
      110,  234,   84,  158,   84,  235,  159, 1121,  160,  239,
     1122,  162,  161,  528,  164,  240,  241,  111,  529,  163,
       84,   87,   84,  180,  112,   84,   87,   84,  167,  187,
      187,  165,  166,  188,  188,   84,   87,   84, 1123,  125,
       84,  182,   84,  172,  350,   84,  250,   84,   86,   86,

      251,  186,  186,  351, 1124,  183,  184,  168,   91,   92,
      117,  169,  121,  119, 1125,  122,  170,   84,   87,   84,
      120,  243,  173,  123, 1126,  244,  126,   84,   87,   84,
      171,  127,  183,  184,  245,   91,   92,   84,   87,   84,
       84,   87,   84, 1127,  190,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  149,  192, 1128,  193,  150, 1131,  191,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  174,  765,  195,  766,  175,  196,   84,   87,
       84,   84,   87,   84,  194,   84,   87,   84,   84,   87,

       84, 1132,  197,   84,   87,   84,   84,   87,   84,  851,
      852,  198,   84,   87,   84,   84,   87,   84,  177,  201,
      200,  199,  178, 1133,  202,   84,   87,   84,   84,   87,
       84,   84,   87,   84,  203,   84,   87,   84, 1134, 1135,
      205,  204,  206,  207,  208, 1136,  210, 1137, 1138,  209,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  323,
      324,  211,  325, 1139,  212,   84,   87,   84,  215,   84,
       87,   84,  188,  188,  214,  217,  329,   84,   87,   84,
       92,  213, 1140,  216,   84,   87,   84,  246,  330,  247,
      804,  331,  248, 1141,  249,   84,   87,   84,  218,   84,

       87,   84,  805,  220,  219, 1142,  221,   92,   84,   87,
       84,   84,   87,   84,  222, 1143, 1146,  223,  224,   84,
       87,   84, 1147, 1148,  225,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84, 1149,  258,   84,
       87,   84,   84,   87,   84,  442,   84,   87,   84,  443,
      259,  260,  613, 1150,  261, 1151,  614,  262,   84,   87,
       84,   84,   87,   84, 1152,   84,   87,   84,   84,   87,
       84, 1155, 1156,  263,   84,   87,   84,  267,  264,   84,
       87,   84,  339, 1157,  266,   84,   87,   84,  340,  265,
      268,   84,   87,   84, 1158,  207,  341,  270,   84,   87,

       84, 1100, 1159,  181,  181,   84,   87,   84,  269,  271,
       91,   92, 1162,  273, 1101, 1163,  187,  280,  272,   84,
      281,  281,  282,  274,   84,   87,   84, 1164,  276, 1166,
      213,  678,  275, 1168,  186,  186,  679,   91,   92, 1170,
      189,   91,   92,   84,   87,   84,  277,   80,   84,   87,
       84,   80,   84,   87,   84, 1107,   84,   87,   84,  279,
      279, 1106,  279,  279,  279,  279,  279,  279,   91,   92,
      285, 1105,  289,  286, 1104,  287,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,  283,  279,
      279,  279,  279,  279,  279,  288, 1103,  284,   84,   87,

       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,  292,   84,   87,   84,
       84,   87,   84, 1102, 1099,  290, 1098, 1097,  291,  293,
       84,   87,   84,   84,   87,   84, 1096,  296, 1095, 1094,
      297,  294,   84,   87,   84,   84,   87,   84, 1093, 1092,
      295, 1087,  298, 1086,  299,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84, 1085,  300,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84, 1084,  301,  302, 1083,  303,   84,   87,   84,   84,
       87,   84, 1082,  304, 1081,  306,   84,   87,   84, 1080,

      305,   84,   87,   84,   84,   87,   84, 1079,   84,   87,
       84,  307, 1078, 1077,  308,  312,   84,   87,   84,  310,
      309,  311, 1076,  313,   84,   87,   84,   84,   87,   84,
       84,   87,   84, 1075, 1074,  314, 1073,  315, 1072, 1071,
      317,  318,   84,   87,   84,   84,   87,   84,   84,   87,
       84,  316,   84,   87,   84,   84,   87,   84, 1070,  362,
     1069,  361,   84,   87,   84,  360,   84,   87,   84,   84,
       87,   84, 1068,  363, 1063,  364,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84, 1062,  365,
       84,   87,   84, 1061,  367,   84,   87,   84, 1060,  368,

       84,   87,   84,  369, 1059,  366,   84,   87,   84, 1058,
      370, 1057,   84,  371,   84,  281,  281,   84, 1056,   84,
      281,  281,   84,   87,   84,  372, 1055,  374,  184, 1054,
      373, 1053,  375,   84,   87,   84, 1052, 1051,  376,   84,
       87,   84,   84,   87,   84,   84,   87,   84, 1050,  377,
       84,   87,   84, 1049,  382,  184,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  383,  380,   84,   87,   84,
     1048,  384, 1047, 1046,  385,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84, 1045,  381,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,

       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
     1044,  386,   84,   87,   84, 1043, 1042,  387,  388, 1041,
     1040,  390,  389,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  391, 1039,  394, 1032, 1031,  395,   84,   87,
       84, 1030,  392, 1029,  396,  734,  735,  393,   84,   87,
       84, 1028, 1027,  397,  736,   84,   87,   84, 1026,  399,
      737,  401, 1025,  400,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  398,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84, 1024,  402, 1023,  403,
      404,   84,   87,   84,   84,   87,   84, 1022,   84,   87,

       84,   84,   87,   84,   84,   87,   84,  405, 1021, 1020,
      407,   84,   87,   84,   84,   87,   84, 1019, 1018,  409,
      406, 1017,  408,   84,   87,   84,   84,   87,   84,   84,
       87,   84, 1016, 1015,  410,  452,   84,   87,   84,   84,
       87,   84,  411,  454,   84,   87,   84,   84,   87,   84,
     1014, 1013,  453,   84,   87,   84,  456, 1012, 1011,   84,
       87,   84,   84,   87,   84,  455,   84,   87,   84,   84,
       87,   84,  457,   84,   87,   84,   84,   87,   84, 1010,
      458,  459,   84,   87,   84,   84,   87,   84,  393, 1009,
      460, 1008,  463, 1007, 1006,  461,  400,   84,   87,   84,

      998,  997,  407,  996,  470,  462,  465,   84,   87,   84,
      467,  464,  995,   84,   87,   84,  466,   84,   87,   84,
      994,  993,  471,  469,  992,  468,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  991,  472,  473,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  990,
       84,   87,   84,   84,   87,   84,  474,  475,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  989,
      988,  479,  987,  986,  476,  480,   84,   87,   84,  985,

      477,  984,  983,  478,   84,   87,   84,  482,   84,   87,
       84,  481,   84,   87,   84,  484,   84,   87,   84,  486,
       84,   87,   84,  982,  483,   84,   87,   84,   84,   87,
       84,  981,  980,  485,   84,   87,   84,   84,   87,   84,
      979,  487,   84,   87,   84,   84,   87,   84,  978,  489,
      977,  976,  490,   84,   87,   84,  975,  488,   84,   87,
       84,  533,  974,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,  973,  972,
      535,  971,  970,  534,  961,  960,  538,   84,   87,   84,
      959,  958,  536,  537,  957,   84,   87,   84,   84,   87,

       84,   84,   87,   84,  956,  955,  541,  539,  540,   84,
       87,   84,   84,   87,   84,  481,  954,  953,  549,   84,
       87,   84,  542,  952,  951,  543,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  544,  545,   84,   87,   84,
      559,  547,  950,  550,  546,  949,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,  948,  548,   84,   87,   84,  563,
       84,   87,   84,  551,  552,  553,  554,  947,  560,  561,
       84,   87,   84,  555,  946,  945,  556,   84,   87,   84,
      557,  558,   84,   87,   84,  562,   84,   87,   84,   84,

       87,   84,  564,   84,   87,   84,  944,  565,   84,   87,
       84,  573,  574,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  943,  942,  575,  576,   84,
       87,   84,  577,  941,  567,  940,  568,   84,   87,   84,
      939,  938,  566,   84,   87,   84,  569,  937,   84,   87,
       84,   84,   87,   84,  618,   84,   87,   84,  570,   84,
       87,   84,   84,   87,   84,  621,  936,  619,  935,  620,
       84,   87,   84,   84,   87,   84,  622,   84,   87,   84,
      623,  624,  934,  625,   84,   87,   84,   84,   87,   84,
      933,  932,  627,   84,   87,   84,   84,   87,   84,  931,

      922,  628,  921,  920,  633,  919,  626,  918,  917,  631,
       84,   87,   84,  916,  629,  915,  635,  914,  630,  913,
      912,  632,  634,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  911,  910,  636,  909,  639,
       84,   87,   84,  638,  908,  637,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  907,  906,  640,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
      905,  904,  641,  903,  902,  642,   84,   87,   84,  643,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  901,  645,   84,   87,   84,   84,   87,   84,

      900,  899,  644,  898,  647,   84,   87,   84,  897,  646,
       84,   87,   84,   84,   87,   84,  896,  648,   84,   87,
       84,  895,  649,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,  894,  698,  893,  892,  699,  696,   84,   87,   84,
      891,  890,  697,  879,  876,  700,   84,   87,   84,  875,
      701,   84,   87,   84,   84,   87,   84,  874,  873,  702,
      872,  871,  703,   84,   87,   84,   84,   87,   84,  705,
      704,   84,   87,   84,   84,   87,   84,  711,  707,  706,
      870,  869,  713,   84,   87,   84,  709,  710,  712,   84,

       87,   84,   84,   87,   84,  868,   84,   87,   84,  867,
      866,  708,   84,   87,   84,  865,  864,  716,  863,  714,
      717,  862,  861,  715,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  718,   84,   87,   84,  720,   84,   87,
       84,   84,   87,   84,  860,  719,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
      859,  721,   84,   87,   84,  858,  857,  722,   84,   87,
       84,   84,   87,   84,  856,  769,   84,   87,   84,  767,
      855,  854,  768,  853,  770,   84,   87,   84,   84,   87,

       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  850,  849,  771,  848,  847,  772,  846,
      845,  777,  844,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  843,  773,   84,   87,   84,  842,  841,  774,
      778,  827,   84,   87,   84,  826,  825,  780,  775,  824,
      823,  779,  782,  822,  776,   84,   87,   84,  821,  781,
       84,   87,   84,  783,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  820,  785,  819,  818,  784,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  786,

       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  817,  828,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  836,  835,  816,  832,  815,  830,   84,
       87,   84,  829,   84,   87,   84,  814,  813,  831,  812,
      833,  811,  810,  834,   84,   87,   84,   84,   87,   84,
      809,  808,  837,   84,   87,   84,  807,  838,   84,   87,
       84,  806,  803,  839,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  802,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  840,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  801,

      888,  800,  881,  799,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  887,  880,  883,  884,   84,   87,   84,
      798,  882,  886,   84,   87,   84,  797,  796,  885,  889,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  795,  924,  930,   84,   87,   84,   84,
       87,   84,  923,  794,  929,  793,  792,  927,  791,  790,
      925,   84,   87,   84,  926,  789,  962,  788,  787,  928,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,

       87,   84,  963,  969,   84,   87,   84,   84,   87,   84,
      965,  964,  764,  967,  966,   84,   87,   84,   84,   87,
       84,  763,  762,  968,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  999,   84,   87,   84, 1001,  761,  760,
     1000,   84,   87,   84, 1002,   84,   87,   84,   84,   87,
       84,   84,   87,   84, 1003,   84,   87,   84,   84,   87,
       84,  759,  758, 1004,   84,   87,   84,  757,   84,   87,
       84, 1005,   84,   87,   84,  756,  755, 1035, 1065,   84,
       87,   84,  754,  753, 1033,   84,   87,   84, 1037,  752,
     1036, 1034, 1038, 1064,   84,   87,   84,   84,   87,   84,

       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,  751, 1066, 1067,   84,   87,   84,   84,   87,   84,
      750, 1088,   84,   87,   84,   84,   87,   84,  749,  748,
     1091,   84,   87,   84,  747, 1089,   84,   87,   84, 1090,
       84,   87,   84, 1110,   84,   87,   84, 1111,  746, 1154,
       84,   87,   84,  745, 1112,   84,   87,   84, 1129,  744,
     1130,  743,  742, 1144,  741,   84,   87,   84,   84,   87,
       84,  740,  739, 1145,   84,   87,   84, 1153,   84,   87,
       84,  738,  731, 1161,  730, 1160,   84,   87,   84,  729,

      728,  727,  726,  725,  724,  723,  695,  694,  693,  692,
     1165, 1167,  691,  690,  689,  688,  687,  686,  685,  684,
      683, 1169,  682,  681,  680, 1171,  677,  676,  675,  674,
      673,  672, 1172,   46,   46,   46,   46,   50,   50,   50,
       50,   76,   76,   76,   76,   79,   79,   79,   79,   87,
       87,   96,   96,  185,  671,  185,  185,  670,  669,  668,
      667,  666,  665,  664,  663,  662,  661,  660,  659,  658,
      657,  656,  655,  654,  653,  652,  651,  650,  617,  616,
      615,  612,  611,  610,  609,  608,  607,  606,  605,  604,
      603,  602,  601,  600,  599,  598,  597,  596,  595,  594,

      593,  592,  591,  590,  589,  588,  587,  586,  585,  584,
      583,  582,  581,  580,  579,  578,  572,  571,  532,  527,
      526,  525,  524,  523,  522,  521,  520,  519,  518,  517,
      516,  515,  514,  513,  512,  511,  510,  509,  508,  507,
      506,  505,  504,  503,  502,  501,  500,  499,  498,  497,
      496,  495,  494,  493,  492,  491,  451,  450,  449,  448,
      447,  446,  445,  444,  441,  440,  439,  438,  437,  436,
      435,  434,  433,  432,  431,  430,  429,  428,  427,  426,
      425,  424,  423,  422,  421,  420,  419,  418,  417,  416,
      415,  414,  413,  412,  379,  378,  359,  358,  357,  356,

      355,  354,  353,  352,  349,  346,  345,  344,  343,  342,
      338,  337,  336,  333,  332,  328,  327,  326,  320,  319,
      179,  233,  176,  257,  151,  256,  255,  252,  242,  238,
      229,  228, 1173, 1173,  179,  176,  152,  151,  129,   95,
     1173, 1173,   73,   47,   11, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,

     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173
    } ;

static yyconst flex_int16_t yy_chk[2815] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        4,    4,    5,    2,    4,    6,    8,   15, 1086,    5,
        8,   10,    6,    7,   19,   10,   16,   10,   19,   17,
       16,   17,   17,   23,   23,   23,  146,    7,   18,   18,

       18,   18,   18,  236,   24,   24,   24,   25,   25,   25,
      146,    7,   26,   26,   26,   15,   31,   31,   31,    7,
      236,    7,    7, 1087,    7,    7,   16,    7,    7,    7,
       24,    7,    7,  826,    7,    7,    7,    7,    7,   20,
      826,   20,   20, 1092,   26,   27,   27,   27,   20,   20,
       28,   28,   28,   76,  135,   20,   30,   30,   30,   27,
      659,   31,   25,  135,   20,   29,   29,   29,   82,   82,
       31,   32,   32,   32,  659,   20,   20,   33,   33,   33,
     1093,   20,   34,   34,   34,   35,   35,   35,   84,   20,
       84,   76,   20,   36,   36,   36,   28,   37,   37,   37,

      187,  187,   30,   44,   32,   29,   48,   44,   29,   71,
       48,   29,   32,   71,   32,   38,   38,   38,   35,   40,
       40,   40,   33,   39,   39,   39,  450, 1095,   34,   41,
       41,   41,   42,   42,   42,   54,   54,   54,  132,  450,
       36,   55,   55,   55,   87,   37,   87,  138,   37,   56,
       56,   56,  136,   74,  132,   38,   38,   74,   38, 1096,
       39,  136,   79,   39,   40,   38,   79,   42,   54, 1097,
       41,   39,   57,   57,   57,   41,  138,  228,   39,   45,
       45,   45,   45,   45,   45,   45,   45,   45,  228,   55,
       45,   45,   56,  247,   45,  179,   45,   45,   45,   45,

       45,   58,   58,   58,  179,   57, 1098,   59,   59,   59,
       81,  247,   57,  130,   81,   57, 1100,  130,   57,   60,
       60,   60,   61,   61,   61,   62,   62,   62,   63,   63,
       63,   64,   64,   64,   65,   65,   65,  182,   58,  182,
       59,   66,   66,   66,   69,   69,   69,   58,   59, 1101,
       59,  137,  184,   59,  184,  137,   60, 1102,   61,  140,
     1103,   63,   62,  449,   64,  140,  140,   61,  449,   63,
       67,   67,   67,   81,   63,   68,   68,   68,   66,   91,
       91,   65,   65,   91,   91,   70,   70,   70, 1104,   69,
       85,   85,   85,   69,  249,   86,  144,   86,   86,   86,

      144,   90,   90,  249, 1105,   86,   86,   67,   90,   90,
       67,   67,   68,   67, 1106,   68,   68,   96,   96,   96,
       67,  142,   70,   68, 1107,  142,   70,   97,   97,   97,
       68,   70,   86,   86,  142,   90,   90,   98,   98,   98,
       99,   99,   99, 1108,   97,  100,  100,  100,  101,  101,
      101,  102,  102,  102,  103,  103,  103,  104,  104,  104,
      105,  105,  105,  149,   99, 1109,  100,  149, 1113,   98,
      106,  106,  106,  107,  107,  107,  108,  108,  108,  109,
      109,  109,  174,  695,  102,  695,  174,  103,  110,  110,
      110,  111,  111,  111,  101,  112,  112,  112,  113,  113,

      113, 1114,  104,  115,  115,  115,  114,  114,  114,  797,
      797,  105,  116,  116,  116,  117,  117,  117,  177,  108,
      107,  106,  177, 1115,  109,  118,  118,  118,  119,  119,
      119,  121,  121,  121,  110,  120,  120,  120, 1116, 1117,
      112,  111,  113,  114,  115, 1118,  116, 1119, 1120,  115,
      122,  122,  122,  123,  123,  123,  124,  124,  124,  229,
      229,  117,  229, 1122,  118,  125,  125,  125,  120,  126,
      126,  126,  188,  188,  119,  121,  233,  127,  127,  127,
      188,  118, 1124,  120,  128,  128,  128,  143,  233,  143,
      740,  233,  143, 1125,  143,  153,  153,  153,  122,  154,

      154,  154,  740,  124,  123, 1126,  125,  188,  155,  155,
      155,  156,  156,  156,  125, 1128, 1133,  126,  127,  157,
      157,  157, 1136, 1137,  128,  158,  158,  158,  159,  159,
      159,  160,  160,  160,  161,  161,  161, 1138,  153,  162,
      162,  162,  163,  163,  163,  350,  164,  164,  164,  350,
      154,  155,  529, 1139,  156, 1140,  529,  157,  165,  165,
      165,  166,  166,  166, 1141,  167,  167,  167,  168,  168,
      168, 1147, 1148,  158,  169,  169,  169,  163,  159,  170,
      170,  170,  241, 1149,  162,  171,  171,  171,  241,  161,
      164,  172,  172,  172, 1151,  165,  241,  166,  173,  173,

      173, 1076, 1152,  181,  181,  190,  190,  190,  165,  167,
      181,  181, 1156,  169, 1076, 1157,  183,  183,  168,  183,
      183,  183,  190,  170,  195,  195,  195, 1158,  172, 1163,
      169,  600,  171, 1166,  186,  186,  600,  181,  181, 1168,
     1181,  186,  186,  193,  193,  193,  173,  180,  191,  191,
      191,  180,  194,  194,  194, 1085,  192,  192,  192,  180,
      180, 1084,  180,  180,  180,  180,  180,  180,  186,  186,
      192, 1083,  195,  192, 1081,  193,  196,  196,  196,  197,
      197,  197,  198,  198,  198,  199,  199,  199,  191,  180,
      180,  180,  180,  180,  180,  194, 1079,  191,  200,  200,

      200,  201,  201,  201,  202,  202,  202,  203,  203,  203,
      204,  204,  204,  205,  205,  205,  198,  206,  206,  206,
      207,  207,  207, 1078, 1075,  196, 1074, 1073,  197,  199,
      208,  208,  208,  209,  209,  209, 1072,  202, 1071, 1070,
      203,  200,  210,  210,  210,  211,  211,  211, 1069, 1068,
      201, 1063,  205, 1062,  206,  212,  212,  212,  213,  213,
      213,  214,  214,  214,  215,  215,  215, 1060,  207,  216,
      216,  216,  217,  217,  217,  218,  218,  218,  219,  219,
      219, 1059,  208,  209, 1058,  210,  220,  220,  220,  221,
      221,  221, 1057,  211, 1056,  213,  222,  222,  222, 1055,

      212,  223,  223,  223,  224,  224,  224, 1054,  225,  225,
      225,  214, 1053, 1052,  215,  219,  258,  258,  258,  217,
      216,  218, 1049,  220,  259,  259,  259,  260,  260,  260,
      261,  261,  261, 1048, 1047,  221, 1046,  222, 1044, 1043,
      224,  225,  262,  262,  262,  263,  263,  263,  264,  264,
      264,  223,  265,  265,  265,  266,  266,  266, 1042,  260,
     1041,  259,  267,  267,  267,  258,  268,  268,  268,  269,
      269,  269, 1040,  261, 1032,  262,  270,  270,  270,  271,
      271,  271,  272,  272,  272,  273,  273,  273, 1031,  263,
      274,  274,  274, 1030,  266,  275,  275,  275, 1029,  267,

      277,  277,  277,  268, 1027,  265,  276,  276,  276, 1026,
      269, 1025,  280,  270,  280,  280,  280,  281, 1024,  281,
      281,  281,  282,  282,  282,  271, 1022,  274,  281, 1021,
      273, 1020,  275,  283,  283,  283, 1019, 1018,  276,  284,
      284,  284,  285,  285,  285,  286,  286,  286, 1017,  277,
      287,  287,  287, 1016,  285,  281,  288,  288,  288,  289,
      289,  289,  290,  290,  290,  286,  283,  291,  291,  291,
     1015,  287, 1014, 1013,  287,  292,  292,  292,  293,  293,
      293,  294,  294,  294,  295,  295,  295, 1012,  284,  296,
      296,  296,  297,  297,  297,  298,  298,  298,  299,  299,

      299,  300,  300,  300,  301,  301,  301,  302,  302,  302,
     1011,  290,  303,  303,  303, 1010, 1009,  291,  292, 1008,
     1007,  295,  294,  304,  304,  304,  305,  305,  305,  306,
      306,  306,  296, 1006,  300,  998,  997,  301,  307,  307,
      307,  996,  297,  995,  302,  661,  661,  299,  308,  308,
      308,  994,  992,  303,  661,  309,  309,  309,  991,  305,
      661,  306,  990,  305,  310,  310,  310,  311,  311,  311,
      312,  312,  312,  304,  313,  313,  313,  314,  314,  314,
      315,  315,  315,  316,  316,  316,  989,  307,  987,  308,
      309,  317,  317,  317,  318,  318,  318,  986,  360,  360,

      360,  361,  361,  361,  362,  362,  362,  310,  985,  984,
      313,  363,  363,  363,  364,  364,  364,  983,  982,  315,
      311,  981,  314,  365,  365,  365,  366,  366,  366,  367,
      367,  367,  980,  979,  316,  360,  368,  368,  368,  369,
      369,  369,  318,  363,  370,  370,  370,  371,  371,  371,
      978,  977,  362,  372,  372,  372,  365,  976,  975,  373,
      373,  373,  374,  374,  374,  364,  375,  375,  375,  377,
      377,  377,  366,  376,  376,  376,  380,  380,  380,  974,
      367,  368,  381,  381,  381,  382,  382,  382,  369,  973,
      370,  972,  373,  971,  970,  371,  373,  383,  383,  383,

      961,  960,  375,  959,  382,  372,  376,  384,  384,  384,
      377,  374,  958,  385,  385,  385,  376,  386,  386,  386,
      956,  955,  383,  381,  954,  380,  387,  387,  387,  388,
      388,  388,  389,  389,  389,  953,  384,  385,  390,  390,
      390,  391,  391,  391,  392,  392,  392,  393,  393,  393,
      394,  394,  394,  395,  395,  395,  396,  396,  396,  952,
      397,  397,  397,  398,  398,  398,  388,  389,  399,  399,
      399,  400,  400,  400,  401,  401,  401,  402,  402,  402,
      403,  403,  403,  404,  404,  404,  405,  405,  405,  950,
      949,  396,  948,  947,  393,  397,  406,  406,  406,  946,

      394,  945,  944,  395,  407,  407,  407,  400,  408,  408,
      408,  399,  409,  409,  409,  403,  410,  410,  410,  405,
      411,  411,  411,  943,  401,  452,  452,  452,  453,  453,
      453,  942,  941,  404,  454,  454,  454,  455,  455,  455,
      940,  407,  456,  456,  456,  457,  457,  457,  939,  410,
      938,  937,  411,  458,  458,  458,  936,  409,  459,  459,
      459,  453,  935,  460,  460,  460,  461,  461,  461,  462,
      462,  462,  463,  463,  463,  464,  464,  464,  934,  933,
      455,  932,  931,  454,  922,  921,  458,  465,  465,  465,
      920,  919,  456,  457,  918,  466,  466,  466,  467,  467,

      467,  468,  468,  468,  917,  915,  462,  459,  460,  469,
      469,  469,  470,  470,  470,  463,  914,  913,  470,  471,
      471,  471,  463,  912,  911,  464,  473,  473,  473,  474,
      474,  474,  478,  478,  478,  465,  466,  475,  475,  475,
      473,  468,  910,  471,  467,  909,  476,  476,  476,  477,
      477,  477,  479,  479,  479,  480,  480,  480,  481,  481,
      481,  482,  482,  482,  908,  469,  472,  472,  472,  478,
      483,  483,  483,  472,  472,  472,  472,  906,  475,  476,
      484,  484,  484,  472,  905,  904,  472,  485,  485,  485,
      472,  472,  486,  486,  486,  477,  487,  487,  487,  488,

      488,  488,  479,  489,  489,  489,  903,  481,  490,  490,
      490,  493,  493,  533,  533,  533,  534,  534,  534,  535,
      535,  535,  536,  536,  536,  902,  901,  493,  493,  537,
      537,  537,  493,  900,  487,  899,  488,  538,  538,  538,
      898,  897,  486,  539,  539,  539,  489,  896,  540,  540,
      540,  541,  541,  541,  533,  542,  542,  542,  490,  543,
      543,  543,  544,  544,  544,  537,  895,  534,  894,  535,
      545,  545,  545,  546,  546,  546,  538,  547,  547,  547,
      539,  540,  893,  541,  548,  548,  548,  549,  549,  549,
      892,  891,  543,  550,  550,  550,  551,  551,  551,  890,

      879,  544,  878,  877,  549,  876,  542,  875,  874,  547,
      552,  552,  552,  873,  545,  872,  552,  871,  546,  870,
      868,  548,  551,  553,  553,  553,  554,  554,  554,  555,
      555,  555,  556,  556,  556,  864,  863,  553,  862,  556,
      557,  557,  557,  555,  861,  554,  558,  558,  558,  559,
      559,  559,  560,  560,  560,  860,  859,  557,  561,  561,
      561,  562,  562,  562,  563,  563,  563,  564,  564,  564,
      858,  857,  558,  856,  855,  558,  565,  565,  565,  559,
      566,  566,  566,  567,  567,  567,  568,  568,  568,  569,
      569,  569,  854,  561,  570,  570,  570,  618,  618,  618,

      853,  852,  560,  851,  564,  619,  619,  619,  850,  562,
      620,  620,  620,  621,  621,  621,  849,  566,  622,  622,
      622,  848,  568,  623,  623,  623,  624,  624,  624,  625,
      625,  625,  626,  626,  626,  627,  627,  627,  628,  628,
      628,  847,  620,  846,  845,  621,  618,  629,  629,  629,
      844,  843,  619,  827,  825,  622,  630,  630,  630,  824,
      623,  631,  631,  631,  632,  632,  632,  823,  822,  624,
      820,  819,  625,  633,  633,  633,  634,  634,  634,  627,
      626,  635,  635,  635,  636,  636,  636,  634,  629,  628,
      818,  816,  636,  637,  637,  637,  632,  633,  635,  638,

      638,  638,  639,  639,  639,  815,  640,  640,  640,  814,
      813,  631,  641,  641,  641,  812,  811,  639,  810,  637,
      640,  809,  808,  638,  642,  642,  642,  643,  643,  643,
      644,  644,  644,  641,  645,  645,  645,  643,  646,  646,
      646,  647,  647,  647,  807,  642,  648,  648,  648,  649,
      649,  649,  696,  696,  696,  697,  697,  697,  698,  698,
      698,  699,  699,  699,  700,  700,  700,  701,  701,  701,
      806,  645,  702,  702,  702,  805,  804,  647,  703,  703,
      703,  704,  704,  704,  801,  698,  705,  705,  705,  696,
      800,  799,  697,  798,  699,  706,  706,  706,  707,  707,

      707,  708,  708,  708,  709,  709,  709,  710,  710,  710,
      711,  711,  711,  796,  795,  703,  794,  793,  704,  792,
      791,  711,  790,  712,  712,  712,  713,  713,  713,  714,
      714,  714,  789,  705,  715,  715,  715,  788,  787,  706,
      712,  766,  716,  716,  716,  765,  764,  714,  707,  762,
      761,  713,  716,  758,  709,  717,  717,  717,  757,  715,
      718,  718,  718,  717,  719,  719,  719,  720,  720,  720,
      721,  721,  721,  755,  719,  754,  753,  718,  722,  722,
      722,  767,  767,  767,  768,  768,  768,  769,  769,  769,
      770,  770,  770,  771,  771,  771,  772,  772,  772,  720,

      773,  773,  773,  774,  774,  774,  775,  775,  775,  776,
      776,  776,  752,  767,  777,  777,  777,  778,  778,  778,
      779,  779,  779,  778,  777,  751,  771,  750,  769,  780,
      780,  780,  768,  781,  781,  781,  749,  748,  770,  747,
      774,  746,  745,  775,  782,  782,  782,  783,  783,  783,
      744,  743,  782,  784,  784,  784,  742,  783,  785,  785,
      785,  741,  739,  784,  786,  786,  786,  828,  828,  828,
      829,  829,  829,  830,  830,  830,  831,  831,  831,  738,
      832,  832,  832,  833,  833,  833,  834,  834,  834,  786,
      835,  835,  835,  836,  836,  836,  838,  838,  838,  737,

      836,  736,  829,  735,  837,  837,  837,  839,  839,  839,
      840,  840,  840,  835,  828,  831,  832,  880,  880,  880,
      734,  830,  834,  881,  881,  881,  733,  732,  833,  837,
      882,  882,  882,  883,  883,  883,  884,  884,  884,  885,
      885,  885,  886,  886,  886,  887,  887,  887,  888,  888,
      888,  889,  889,  889,  923,  923,  923,  924,  924,  924,
      925,  925,  925,  731,  881,  888,  926,  926,  926,  927,
      927,  927,  880,  730,  886,  729,  728,  884,  727,  726,
      882,  928,  928,  928,  883,  725,  923,  724,  723,  885,
      929,  929,  929,  930,  930,  930,  962,  962,  962,  963,

      963,  963,  924,  930,  964,  964,  964,  965,  965,  965,
      926,  925,  694,  928,  927,  966,  966,  966,  967,  967,
      967,  693,  692,  929,  968,  968,  968,  969,  969,  969,
      999,  999,  999,  962, 1001, 1001, 1001,  964,  691,  690,
      963, 1000, 1000, 1000,  965, 1002, 1002, 1002, 1003, 1003,
     1003, 1005, 1005, 1005,  966, 1004, 1004, 1004, 1033, 1033,
     1033,  689,  687,  967, 1034, 1034, 1034,  686, 1035, 1035,
     1035,  968, 1036, 1036, 1036,  685,  684, 1001, 1035, 1037,
     1037, 1037,  683,  682,  999, 1038, 1038, 1038, 1004,  681,
     1002, 1000, 1005, 1033, 1064, 1064, 1064, 1065, 1065, 1065,

     1066, 1066, 1066, 1067, 1067, 1067, 1088, 1088, 1088, 1089,
     1089, 1089, 1090, 1090, 1090, 1091, 1091, 1091, 1110, 1110,
     1110,  680, 1036, 1037, 1111, 1111, 1111, 1112, 1112, 1112,
      679, 1064, 1129, 1129, 1129, 1130, 1130, 1130,  678,  677,
     1067, 1144, 1144, 1144,  676, 1065, 1145, 1145, 1145, 1066,
     1153, 1153, 1153, 1088, 1160, 1160, 1160, 1089,  674, 1145,
     1154, 1154, 1154,  673, 1091, 1161, 1161, 1161, 1110,  671,
     1111,  669,  668, 1129,  667, 1165, 1165, 1165, 1167, 1167,
     1167,  664,  663, 1130, 1171, 1171, 1171, 1144, 1169, 1169,
     1169,  662,  658, 1154,  657, 1153, 1172, 1172, 1172,  656,

      655,  654,  653,  652,  651,  650,  617,  616,  615,  614,
     1161, 1165,  613,  612,  611,  610,  609,  608,  607,  606,
      605, 1167,  604,  602,  601, 1169,  599,  598,  597,  596,
      595,  594, 1171, 1174, 1174, 1174, 1174, 1175, 1175, 1175,
     1175, 1176, 1176, 1176, 1176, 1177, 1177, 1177, 1177, 1178,
     1178, 1179, 1179, 1180,  592, 1180, 1180,  591,  590,  589,
      588,  587,  586,  585,  584,  583,  582,  581,  580,  579,
      578,  577,  576,  575,  574,  573,  572,  571,  532,  531,
      530,  528,  527,  526,  525,  524,  523,  522,  521,  520,
      519,  518,  517,  516,  515,  514,  513,  512,  511,  510,

      509,  508,  507,  506,  505,  504,  503,  502,  501,  500,
      499,  498,  497,  496,  495,  494,  492,  491,  451,  448,
      447,  446,  445,  444,  443,  442,  441,  440,  439,  438,
      437,  436,  435,  434,  433,  432,  431,  430,  429,  428,
      427,  426,  425,  424,  423,  422,  421,  420,  419,  418,
      417,  416,  415,  414,  413,  412,  358,  357,  356,  355,
      354,  353,  352,  351,  349,  348,  347,  346,  345,  344,
      343,  342,  341,  340,  339,  338,  337,  336,  335,  334,
      333,  332,  331,  330,  329,  327,  326,  325,  324,  323,
      322,  321,  320,  319,  279,  278,  257,  256,  255,  254,

      253,  252,  251,  250,  248,  246,  245,  244,  243,  242,
      240,  238,  237,  235,  234,  232,  231,  230,  227,  226,
      178,  176,  175,  151,  150,  148,  147,  145,  141,  139,
      134,  133,   83,   78,   75,   72,   52,   49,   43,   22,
       21,   11,    9,    3, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,

     1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173, 1173,
     1173, 1173, 1173, 1173
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
/*
 * The SIP lexer.
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 *
 * This file is part of SIP.
 *
 * This copy of SIP is licensed for use under the terms of the SIP License
 * Agreement.  See the file LICENSE for more details.
 *
 * This copy of SIP may also used under the terms of the GNU General Public
 * License v2 or v3 as published by the Free Software Foundation which can be
 * found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
 *
 * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
#line 20 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "sip.h"
#include "parser.h"


#ifndef FLEX_SCANNER
#error "Only flex is supported at the moment"
#endif


/* Windows doesn't have unistd.h so declare it here. */
extern int isatty(int);


/* These are unused. */
static int input(void) SIP_UNUSED;
static void yy_fatal_error(yyconst char *) SIP_UNUSED;
static int yy_top_state(void) SIP_UNUSED;
static void yyunput(int, char *) SIP_UNUSED;

#define YY_NO_UNISTD_H
#define YY_FATAL_ERROR(s)       fatallex(s)

#define MAX_INCLUDE_DEPTH       10
#define MAX_CODE_LINE_LENGTH    1000


static struct inputFile {
    sourceLocation sloc;                /* The source location. */
    YY_BUFFER_STATE bs;                 /* The flex buffer state handle. */
    char *cwd;                          /* The path part of the file name. */
    parserContext pc;                   /* The parser context. */
} inputFileStack[MAX_INCLUDE_DEPTH];

static int currentFile;                 /* Index of the current input file. */
static char codeLine[MAX_CODE_LINE_LENGTH + 2]; /* The current code line. */
static int codeIdx;                     /* Index of next code character. */
static int parenDepth;                  /* The current depth of (...). */
static stringList *allFiles;            /* The list of all input files. */

static FILE *openFile(const char *);
static void fatallex(char *);




#line 1529 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/lexer.c"

#define INITIAL 0
#define code 1
#define ccomment 2
#define directive 3
#define directive_start 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
    static int yy_top_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 75 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"


#line 1731 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/lexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1174 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2745 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 77 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_AUTOPYNAME;}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 78 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_COMPOMODULE;}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 79 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFDOCSTRFMT;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 80 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFDOCSTRSIG;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 81 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFENCODING;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 82 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFMETATYPE;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 83 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFSUPERTYPE;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 84 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_END;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 85 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN INITIAL; return TK_END;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 86 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_EXCEPTION;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 87 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_FEATURE;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 88 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_HIDE_NS;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 89 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_IF;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 90 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_IMPORT;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 91 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_INCLUDE;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 92 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_LICENSE;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 93 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_MAPPEDTYPE;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 94 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_MODULE;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 95 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PLATFORMS;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 96 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_PLUGIN;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 97 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_PROPERTY;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 98 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_TIMELINE;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 100 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_CLASS;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 101 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_STRUCT;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 102 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_UNION;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 103 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PUBLIC;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 104 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PROTECTED;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 105 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PRIVATE;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 106 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNALS;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 107 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNALS;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 108 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNAL_METHOD;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 109 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SLOTS;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 110 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SLOTS;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 111 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SLOT_METHOD;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 112 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_CHAR;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 113 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_WCHAR_T;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 114 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_BOOL;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 115 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SHORT;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 116 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_INT;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 117 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_LONG;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 118 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_FLOAT;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 119 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_DOUBLE;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 120 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_VOID;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 121 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_VIRTUAL;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 122 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_ENUM;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 123 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNED;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 124 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_UNSIGNED;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 125 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_CONST;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 126 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_STATIC;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 127 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_TRUE_VALUE;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 128 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_FALSE_VALUE;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 129 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_NULL_VALUE;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 130 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_TYPEDEF;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 131 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_NAMESPACE;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 132 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_OPERATOR;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 133 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_THROW;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 134 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_EXPLICIT;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 135 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_TEMPLATE;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 136 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_FINAL;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 137 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SIZET;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 138 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SCOPE;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 139 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_LOGICAL_OR;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 140 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_ELLIPSIS;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 141 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYOBJECT;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 142 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYTUPLE;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 143 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYLIST;}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 144 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYDICT;}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 145 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYCALLABLE;}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 146 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYSLICE;}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 147 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYTYPE;}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 148 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYBUFFER;}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 149 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYENUM;}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 150 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYHASHT;}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 151 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_PYSSIZET;}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 153 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /*
     * Remove in v7.0.  It should have been removed in v6.0 but we accidentally
     * left some occurences in PyQt5.
     */
    return TK_PYSSIZET;
}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 161 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_FORMAT;}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 162 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_GET;}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 163 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_ID;}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 164 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_KWARGS;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 165 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_LANGUAGE;}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 166 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_LICENSEE;}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 167 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_NAME;}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 168 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_OPTIONAL;}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 169 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_ORDER;}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 170 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_REMOVELEADING;}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 171 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SET;}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 172 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNATURE;}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 173 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_TIMESTAMP;}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 174 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_TYPE;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 175 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_USEARGNAMES;}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 176 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_USELIMITEDAPI;}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 177 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_ALLRAISEPYEXC;}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 178 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_CALLSUPERINIT;}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 179 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_DEFERRORHANDLER;}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 180 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_VERSION;}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 182 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_TRUE_VALUE;}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 183 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{return TK_FALSE_VALUE;}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 186 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore whitespace. */
    ;
}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 191 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /*
     * Maintain the parenthesis depth so that we don't enter the 'code' state
     * until any arguments have been parsed.
     */
    ++parenDepth;

    BEGIN directive;

    return '(';
}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 203 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* Maintain the parenthesis depth. */
    --parenDepth;

    BEGIN INITIAL;

    return ')';
}
	YY_BREAK
case 101:
/* rule 101 can match eol */
YY_RULE_SETUP
#line 212 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* Maintain the line number. */
    ++inputFileStack[currentFile].sloc.linenr;

    if (codeIdx == 0 && parenDepth == 0)
    {
        BEGIN code;
    }
}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 222 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore C++ style comments. */
    ;
}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 228 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* A signed decimal number. */
    yylval.number = strtol(yytext,NULL,0);
    return TK_NUMBER_VALUE;
}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 235 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* A floating point number. */
    yylval.real = strtod(yytext,NULL);
    return TK_REAL_VALUE;
}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 242 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* An unsigned hexadecimal number. */
    yylval.number = strtol(yytext,NULL,16);
    return TK_NUMBER_VALUE;
}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 249 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* An identifier name. */
    yylval.text = sipStrdup(yytext);
    return TK_NAME_VALUE;
}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 256 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* A relative pathname. */
    yylval.text = sipStrdup(yytext);
    return TK_PATH_VALUE;
}
	YY_BREAK
case 108:
/* rule 108 can match eol */
YY_RULE_SETUP
#line 263 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* A double-quoted string. */
    char ch, *dp, *sp;

    /*
     * Copy the string without the quotes and interpret any standard escape
     * characters.
     */
    yylval.text = sipMalloc(strlen(yytext) - 2 + 1);

    dp = yylval.text;
    sp = yytext + 1;

    while ((ch = *sp++) != '"' && ch != '\0')
    {
        if (ch == '\\')
        {
            ch = *sp++;

            if (ch == 'n')
                ch = '\n';
            else if (ch == 'r')
                ch = '\r';
            else if (ch == 't')
                ch = '\t';
        }

        *dp++ = ch;
    }

    *dp = '\0';

    return TK_STRING_VALUE;
}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 299 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* A single-quoted hex encoded character. */
    yylval.qchar = strtol(&yytext[3], NULL, 16);

    return TK_QCHAR_VALUE;
}
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 307 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* A single-quoted character. */
    if (strlen(yytext) != 3)
        fatallex("Exactly one character expected between single quotes");

    yylval.qchar = yytext[1];

    return TK_QCHAR_VALUE;
}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 318 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore C-style comments. */
    yy_push_state(ccomment);
}
	YY_BREAK
case 112:
/* rule 112 can match eol */
YY_RULE_SETUP
#line 322 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    ++inputFileStack[currentFile].sloc.linenr;
}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 325 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    yy_pop_state();
}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 328 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    ;
}
	YY_BREAK

/*
 * Remove these in SIP v7.  They are retained (but ignored) so that PyQt5 can
 * be built with SIP v6.
 */

case 115:
YY_RULE_SETUP
#line 340 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a read buffer code block. */
    codeIdx = 0;
    return TK_READBUFFERCODE;
}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 346 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a write buffer code block. */
    codeIdx = 0;
    return TK_WRITEBUFFERCODE;
}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 352 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a segment count code block. */
    codeIdx = 0;
    return TK_SEGCOUNTCODE;
}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 358 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a char buffer code block. */
    codeIdx = 0;
    return TK_CHARBUFFERCODE;
}
	YY_BREAK

/* End of deprecated directives. */

case 119:
YY_RULE_SETUP
#line 369 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The software license. */
    codeIdx = 0;
    return TK_COPYING;
}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 375 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a from-type code block. */
    codeIdx = 0;
    return TK_FROMTYPE;
}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 381 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a to-type code block. */
    codeIdx = 0;
    return TK_TOTYPE;
}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 387 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a release code block. */
    codeIdx = 0;
    return TK_RELEASE;
}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 393 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a to-sub-class code block. */
    codeIdx = 0;
    return TK_TOSUBCLASS;
}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 399 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an exported header code block. */
    codeIdx = 0;
    return TK_EXPHEADERCODE;
}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 405 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of part of an extract. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_EXTRACT;
}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 414 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a module header code block. */
    codeIdx = 0;
    return TK_MODHEADERCODE;
}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 420 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type header code block. */
    codeIdx = 0;
    return TK_TYPEHEADERCODE;
}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 426 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a pre-initialisation code block. */
    codeIdx = 0;
    return TK_PREINITCODE;
}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 432 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an initialisation code block. */
    codeIdx = 0;
    return TK_INITCODE;
}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 438 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a post-initialisation code block. */
    codeIdx = 0;
    return TK_POSTINITCODE;
}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 444 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a class finalisation code block. */
    codeIdx = 0;
    return TK_FINALCODE;
}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 450 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a unit code block. */
    codeIdx = 0;
    return TK_UNITCODE;
}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 456 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a unit post-include code block. */
    codeIdx = 0;
    return TK_UNITPOSTINCLUDECODE;
}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 462 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a module code block. */
    codeIdx = 0;
    return TK_MODCODE;
}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 468 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type code block. */
    codeIdx = 0;
    return TK_TYPECODE;
}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 474 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ method code block. */
    codeIdx = 0;
    return TK_METHODCODE;
}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 480 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ code block to insert before the MethodCode. */
    codeIdx = 0;
    return TK_PREMETHODCODE;
}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 486 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ virtual call code block. */
    codeIdx = 0;
    return TK_VIRTUALCALLCODE;
}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 492 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ virtual code block. */
    codeIdx = 0;
    return TK_VIRTUALCATCHERCODE;
}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 498 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a traverse code block. */
    codeIdx = 0;
    return TK_TRAVERSECODE;
}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 504 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a clear code block. */
    codeIdx = 0;
    return TK_CLEARCODE;
}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 510 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a get buffer code block. */
    codeIdx = 0;
    return TK_GETBUFFERCODE;
}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 516 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a release buffer code block. */
    codeIdx = 0;
    return TK_RELEASEBUFFERCODE;
}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 522 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a create instance code block. */
    codeIdx = 0;
    return TK_INSTANCECODE;
}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 528 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a pickle code block. */
    codeIdx = 0;
    return TK_PICKLECODE;
}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 534 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a raise Python exception code block. */
    codeIdx = 0;
    return TK_RAISECODE;
}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 540 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an exported type hint code block. */
    codeIdx = 0;
    return TK_EXPTYPEHINTCODE;
}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 546 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type hint code block. */
    codeIdx = 0;
    return TK_TYPEHINTCODE;
}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 552 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a docstring block. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_DOCSTRING;
}
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 561 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an access code block. */
    codeIdx = 0;
    return TK_ACCESSCODE;
}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 567 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a get code block. */
    codeIdx = 0;
    return TK_GETCODE;
}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 573 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a set code block. */
    codeIdx = 0;
    return TK_SETCODE;
}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 579 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The start of part of a virtual error handler. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_VIRTERRORHANDLER;
}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 588 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The end of a code block. */
    BEGIN INITIAL;
    codeIdx = -1;
    return TK_END;
}
	YY_BREAK
case 155:
/* rule 155 can match eol */
YY_RULE_SETUP
#line 595 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The end of a code line . */
    struct inputFile *ifp;

    codeLine[codeIdx] = '\n';
    codeLine[codeIdx + 1] = '\0';
    codeIdx = 0;

    ifp = &inputFileStack[currentFile];

    yylval.codeb = sipMalloc(sizeof (codeBlock));

    yylval.codeb->frag = sipStrdup(codeLine);
    yylval.codeb->linenr = ifp->sloc.linenr++;
    yylval.codeb->filename = ifp->sloc.name;

    return TK_CODELINE;
}
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 614 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* The contents of a code line. */
    if (codeIdx == MAX_CODE_LINE_LENGTH)
        fatallex("Line is too long");

    codeLine[codeIdx++] = yytext[0];
}
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 622 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
{
    /* Anything else is returned as is. */
    return yytext[0];
}
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 627 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"
ECHO;
	YY_BREAK
#line 2927 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/lexer.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(code):
case YY_STATE_EOF(ccomment):
case YY_STATE_EOF(directive):
case YY_STATE_EOF(directive_start):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1174 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1174 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 1173);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n, i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc(new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 627 "/private/var/folders/0h/xjy657x50x3dzwsjnhfztbcr0000gn/T/tmp_5fh90gg/sip/code_generator/metasrc/lexer.l"



/*
 * Hook into EOF handling.  Return 0 if there is more to process.
 */

int yywrap(void)
{
    char *cwd;
    struct inputFile *ifp;

    if ((cwd = inputFileStack[currentFile].cwd) != NULL)
        free(cwd);

    ifp = &inputFileStack[currentFile--];

    /* Tell the parser if this is the end of a file. */
    parserEOF(ifp->sloc.name, &ifp->pc);

    /*
     * Tidy up this file.  Note that we don't free the filename as it will
     * still be referenced for use in error messages.
     */
    fclose(yyin);

    /* See if this was the original file. */
    if (currentFile < 0)
        return 1;

    yy_delete_buffer(YY_CURRENT_BUFFER);
    yy_switch_to_buffer(ifp->bs);

    return 0;
}


/*
 * Initialise the lexer.
 */
void initialiseLexer(void)
{
    /* Initialise all the globals. */
    currentFile = -1;
    codeIdx = -1;
    parenDepth = 0;
    allFiles = NULL;
}


/*
 * Get the current source location.
 */
void getSourceLocation(sourceLocation *slp)
{
    int cf;

    /*
     * Assume that we will already have gone past the newline but watch out in
     * case we have gone past the end of the file.
     */
    if ((cf = currentFile) < 0)
    {
        /* This will be valid if we have been called. */
        cf = 0;
    }

    slp->linenr = inputFileStack[cf].sloc.linenr - 1;
    slp->name = inputFileStack[cf].sloc.name;
}


/*
 * Set up an input file to be read by the lexer, opening it if necessary.  TRUE
 * is returned if the file has not already been read.
 */
int setInputFile(FILE *open_fp, parserContext *pc, int optional)
{
    char *cwd, *fullname = NULL;
    FILE *fp = open_fp;

    if (currentFile >= MAX_INCLUDE_DEPTH - 1)
        fatal("Too many nested %%Include, %%OptionalInclude or %%Import statements\n");

    if (fp != NULL || (fp = openFile(pc->filename)) != NULL)
        fullname = sipStrdup(pc->filename);
    else
    {
        char *cwd;

        /* Try the directory that contains the current file. */
        if (currentFile >= 0 && (cwd = inputFileStack[currentFile].cwd) != NULL)
        {
            fullname = concat(cwd, "/", pc->filename, NULL);

            if ((fp = openFile(fullname)) == NULL)
            {
                free(fullname);
                fullname = NULL;
            }
        }
    }

    /* Try the include path if we haven't found anything yet. */
    if (fullname == NULL)
    {
        stringList *sl;

        fullname = NULL;

        for (sl = includeDirList; sl != NULL; sl = sl -> next)
        {
            if (fullname != NULL)
                free(fullname);

            fullname = concat(sl->s, "/", pc->filename, NULL);

            if ((fp = openFile(fullname)) != NULL)
                break;
        }

        if (fp == NULL)
        {
            if (optional)
                return FALSE;

            fatal("Unable to find file \"%s\"\n", pc->filename);
        }
    }

    /*
     * If we have just opened the file, make sure that we haven't already read
     * it.  While it should never happen with normal modules (if the user
     * doesn't specify recursive %Imports or %Includes) it is likely to happen
     * with consolidated modules.
     */
    if (open_fp == NULL)
    {
        stringList *sl;

        for (sl = allFiles; sl != NULL; sl = sl->next)
            if (strcmp(sl->s, fullname) == 0)
            {
                fclose(fp);
                return FALSE;
            }
    }

    /* Remember the filename. */
    appendString(&allFiles, sipStrdup(fullname));

    yyin = fp;

    ++currentFile;

    /* Remember the directory containing the new file and make it "current". */
    if ((cwd = strchr(fullname, '/')) != NULL)
    {
        cwd = sipStrdup(fullname);
        *strrchr(cwd,'/') = '\0';
    }

    inputFileStack[currentFile].sloc.linenr = 1;
    inputFileStack[currentFile].sloc.name = fullname;
    inputFileStack[currentFile].pc = *pc;
    inputFileStack[currentFile].cwd = cwd;

    if (currentFile > 0)
    {
        inputFileStack[currentFile].bs = YY_CURRENT_BUFFER;
        yy_switch_to_buffer(yy_create_buffer(yyin,YY_BUF_SIZE));
    }

    return TRUE;
}


/*
 * Open a file for reading or return NULL if it doesn't exist.  Any other error
 * is fatal.
 */
static FILE *openFile(const char *name)
{
    FILE *fp;

    if ((fp = fopen(name,"r")) == NULL && errno != ENOENT)
        fatal("Error in opening file %s\n",name);

    return fp;
}


/*
 * Handle fatal yacc errors.
 */
void yyerror(char *s)
{
    if (currentFile < 0)
        fatal("%s\n", s);

    fatal("%s:%d: %s\n", inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, s);
}


/*
 * Handle warnings while parsing.
 */
void yywarning(char *s)
{
    warning(ParserWarning, "%s:%d: %s\n",
            inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, s);
}


/*
 * Handle deprecation warnings.
 */
void deprecated(const char *msg)
{
    warning(DeprecationWarning, "%s:%d: %s\n",
            inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, msg);
}


/*
 * Handle fatal lex errors.
 */
static void fatallex(char *s)
{
    fatal("%s:%d: Lexical analyser error: %s\n",
        inputFileStack[currentFile].sloc.name,
        inputFileStack[currentFile].sloc.linenr,
        s);
}


/*
 * Reset the lexer state to INITIAL.  This is used by directives that allow an
 * argument to be given without parentheses to get out of the 'directive_start'
 * state before an opening parenthesis is seen in another context.
 */
void resetLexerState(void)
{
    BEGIN INITIAL;
}

